@@ -76,8 +76,8 @@ class PaddleWrap(object):
         # strategy:             finetune的策略。默认为None，此时会使用DefaultFinetuneStrategy策略。
         self.config = hub.RunConfig(
             use_cuda=self.use_cuda,
-            num_epoch=10,
-            batch_size=32,
+            num_epoch=10 if self.use_cuda else 1,
+            batch_size=32 if self.use_cuda else 16,
             log_interval=10,
             eval_interval=50,
             checkpoint_dir='ckpt_model',
